@@ -17,9 +17,13 @@ class AlignRequest(BasicMasterRequest):
         BasicMasterRequest.__init__(self, None, target_host, target_port, use_transition, no_samples, content)
 
     def run(self):
-        uri = "http://" + self.target_host + ":" + self.target_port + "/performAlignments?keyphrase=" + KEYPHRASE + "&use_transition=" + str(
-            self.use_transition) + "&no_samples=" + str(self.no_samples) + "&process=" + str(
-            self.process)
+        try:
+            uri = "http://" + self.target_host + ":" + self.target_port + "/performAlignments?keyphrase=" + KEYPHRASE + "&use_transition=" + str(
+                self.use_transition) + "&no_samples=" + str(self.no_samples) + "&process=" + str(
+                self.process)
 
-        r = requests.post(uri, data=json.dumps(self.content))
-        self.content = json.loads(r.text)
+            r = requests.post(uri, data=json.dumps(self.content))
+            self.content = json.loads(r.text)
+        except:
+            self.content = r.text
+            raise Exception(r.text)
